package io.card.payment;

import android.os.Parcel;
import android.os.Parcelable;

public class CardConfig implements Parcelable {

    private CardType cardType;
    private CardScanSide cardScanSide;
    private String frontSideInstruction;
    private String backSideInstruction;
    private boolean isFlashOn;
    private boolean isToOcr;

    public CardConfig(Builder builder) {
        this.cardType = builder.cardType;
        this.cardScanSide = builder.cardScanSide;
        this.frontSideInstruction = builder.frontSideInstruction;
        this.backSideInstruction = builder.backSideInstruction;
        this.isFlashOn = builder.isFlashOn;
        this.isToOcr = builder.isToOcr;
    }

    public CardConfig(Parcel in) {
        this.cardType = CardType.valueOf(in.readString());
        this.cardScanSide = CardScanSide.valueOf(in.readString());
        this.frontSideInstruction = in.readString();
        this.backSideInstruction = in.readString();
        this.isFlashOn = in.readByte() != 0;
        this.isToOcr = in.readByte() != 0;
    }

    public CardType getCardType() {
        return cardType;
    }

    public CardScanSide getCardScanSide() {
        return cardScanSide;
    }

    public String getFrontSideInstruction() {
        return frontSideInstruction;
    }

    public String getBackSideInstruction() {
        return backSideInstruction;
    }

    public boolean isFlashOn() {
        return isFlashOn;
    }

    public boolean isToOcr() {
        return isToOcr;
    }

    @Override
    public int describeContents() {
        return 0;
    }

    public static final Creator<CardConfig> CREATOR = new Creator<CardConfig>() {
        @Override
        public CardConfig createFromParcel(Parcel in) {
            return new CardConfig(in);
        }

        @Override
        public CardConfig[] newArray(int size) {
            return new CardConfig[size];
        }
    };

    @Override
    public void writeToParcel(Parcel dest, int flags) {
        dest.writeString(cardType.name());
        dest.writeString(cardScanSide.name());
        dest.writeString(frontSideInstruction);
        dest.writeString(backSideInstruction);
        dest.writeByte((byte) (isFlashOn ? 1 : 0));
        dest.writeByte((byte) (isToOcr ? 1 : 0));
    }

    public enum CardScanSide {
        FRONT, BACK, BOTH
    }

    public enum CardType {
        SNIC
    }

    public static final class Builder {
        private CardType cardType = CardType.SNIC;
        private CardScanSide cardScanSide = CardScanSide.BOTH;
        private String frontSideInstruction = "Please scan the front-side of your card";
        private String backSideInstruction = "Please scan the backside of your card";
        private boolean isFlashOn = false;
        private boolean isToOcr = true;

        public Builder() {
        }

//        public Builder setCardType(CardType cardType) {
//            this.cardType = cardType;
//            return this;
//        }

        public Builder setCardScanSide(CardScanSide cardScanSide) {
            this.cardScanSide = cardScanSide;
            return this;
        }

        public Builder setFrontSideInstruction(String instruction) {
            this.frontSideInstruction = instruction;
            return this;
        }

        public Builder setBackSideInstruction(String instruction) {
            this.backSideInstruction = instruction;
            return this;
        }

//        public Builder setIsToOcr(boolean isToOcr) {
//            this.isToOcr = isToOcr;
//            return this;
//        }

        public Builder setIsFlashOn(boolean isFlashOn) {
            this.isFlashOn = isFlashOn;
            return this;
        }

        public CardConfig build() {
            return new CardConfig(this);
        }
    }
}
